@@ -110,7 +110,7 @@ static void *_run_script(void *arg)
 			(void) close(i);
 		setpgid(0, 0);
 		execve(argv[0], argv, script_arg->my_env);
-		exit(127);
+		_exit(127);
 	}
 
 	/* Start tracking this new process */
@@ -173,6 +173,8 @@ static char **_build_env(job_record_t *job_ptr, bool is_epilog)
 	if (job_ptr->spank_job_env_size) {
 		env_array_merge(&my_env,
 				(const char **) job_ptr->spank_job_env);
+		valid_spank_job_env(my_env, job_ptr->spank_job_env_size,
+				    job_ptr->user_id);
 	}
 
 	setenvf(&my_env, "SLURM_JOB_ACCOUNT", "%s", job_ptr->account);
