@@ -1021,7 +1021,7 @@ static int _spawn_job_container(stepd_step_rec_t *job)
 			while (true) /* in case of interrupted sleep */
 				sleep(100000);
 
-			exit(1);
+			_exit(1);
 		} else {
 			/*
 			 * Need to exec() something for proctrack/linuxproc to
@@ -1031,7 +1031,7 @@ static int _spawn_job_container(stepd_step_rec_t *job)
 			execl(SLEEP_CMD, "sleep", "100000000", NULL);
 			error("execl: %m");
 			sleep(1);
-			exit(0);
+			_exit(0);
 		}
 	} else if (pid < 0) {
 		error("fork: %m");
@@ -1145,6 +1145,24 @@ static int _spawn_job_container(stepd_step_rec_t *job)
 	step_terminate_monitor_start(job);
 	proctrack_g_signal(job->cont_id, SIGKILL);
 	proctrack_g_wait(job->cont_id);
+
+	/*
+	 * When an event is registered using the cgroups notification API and
+	 * memory is constrained using task/cgroup, the following check needs to
+	 * happen before any memory cgroup hierarchy removal.
+	 *
+	 * The eventfd will be woken up by control file implementation *or*
+	 * when the cgroup is removed. Thus, for the second case (cgroup
+	 * removal) we could be notified with false positive oom events.
+	 *
+	 * acct_gather_profile_fini() and task_g_post_step() can remove the
+	 * cgroup hierarchy if the cgroup implementation of these plugins are
+	 * configured.
+	 */
+	for (uint32_t i = 0; i < job->node_tasks; i++)
+		if (task_g_post_term(job, job->task[i]) == ENOMEM)
+			job->oom_error = true;
+
 	/*
 	 * This function below calls jobacct_gather_fini(). For the case of
 	 * jobacct_gather/cgroup, it ends up doing the cgroup hierarchy cleanup
@@ -1154,7 +1172,6 @@ static int _spawn_job_container(stepd_step_rec_t *job)
 	acct_gather_profile_fini();
 
 	step_terminate_monitor_stop();
-
 	task_g_post_step(job);
 
 fail1:
@@ -1343,6 +1360,10 @@ job_manager(stepd_step_rec_t *job)
 		debug ("Unable to set dumpable to 1");
 #endif /* PR_SET_DUMPABLE */
 
+	/*
+	 * task_g_post_term() needs to be called before
+	 * acct_gather_profile_fini() and task_g_post_step().
+	 */
 	_wait_for_all_tasks(job);
 	acct_gather_profile_endpoll();
 	acct_gather_profile_g_node_step_end();
@@ -1808,12 +1829,12 @@ _fork_all_tasks(stepd_step_rec_t *job, bool *io_initialized)
 			 * and belong in the child.
 			 */
 			if (_pre_task_child_privileged(job, i, &sprivs) < 0)
-				exit(1);
+				_exit(1);
 
  			if (_become_user(job, &sprivs) < 0) {
  				error("_become_user failed: %m");
 				/* child process, should not return */
-				exit(1);
+				_exit(1);
  			}
 
 			/* log_fini(); */ /* note: moved into exec_task() */
@@ -1838,7 +1859,7 @@ _fork_all_tasks(stepd_step_rec_t *job, bool *io_initialized)
 			 *   before they make a call to exec(2).
 			 */
 			if (_exec_wait_child_wait_for_parent (ei) < 0)
-				exit (1);
+				_exit(1);
 
 			exec_task(job, i);
 		}
@@ -2867,7 +2888,7 @@ _run_script_as_user(const char *name, const char *path, stepd_step_rec_t *job,
 				break;
 			}
 		}
-		exit(127);
+		_exit(127);
 	}
 
 	if (exec_wait_signal_child (ei) < 0)
