@@ -103,10 +103,12 @@ typedef struct {
 	int nfds;
 } poll_args_t;
 
+#ifndef NDEBUG
 static int _find_by_ptr(void *x, void *key)
 {
 	return (x == key);
 }
+#endif /*!NDEBUG */
 
 /*
  * Find by matching fd to connection
@@ -355,6 +357,11 @@ static void _close_con(bool locked, con_mgr_fd_t *con)
 		_check_magic_mgr(con->mgr);
 	}
 
+	/* unlink socket to avoid leaving ghost socket */
+	if (con->unix_socket && (unlink(con->unix_socket) == -1))
+		error("%s: unable to unlink %s: %m",
+		      __func__, con->unix_socket);
+
 	/* mark it as EOF even if it hasn't */
 	con->read_eof = true;
 
@@ -742,8 +749,9 @@ static void _handle_write(void *x)
 		 * not all data written, need to shift it to start of
 		 * buffer and fix offset
 		 */
-		memcpy(get_buf_data(con->out), (get_buf_data(con->out) + wrote),
-		       (get_buf_offset(con->out) - wrote));
+		memmove(get_buf_data(con->out),
+			(get_buf_data(con->out) + wrote),
+			(get_buf_offset(con->out) - wrote));
 
 		/* reset start of offset to end of previous data */
 		set_buf_offset(con->out, (get_buf_offset(con->out) - wrote));
@@ -785,17 +793,16 @@ static void _wrap_on_data(void *x)
 		return;
 	}
 
-	xassert(get_buf_offset(con->in) >= 0);
 	if (get_buf_offset(con->in) < size_buf(con->in)) {
 		if (get_buf_offset(con->in) > 0) {
 			/*
 			 * not all data read, need to shift it to start of
 			 * buffer and fix offset
 			 */
-			memcpy(get_buf_data(con->in),
-			       (get_buf_data(con->in) +
-				get_buf_offset(con->in)),
-			       remaining_buf(con->in));
+			memmove(get_buf_data(con->in),
+				(get_buf_data(con->in) +
+				 get_buf_offset(con->in)),
+				remaining_buf(con->in));
 
 			/* reset start of offset to end of previous data */
 			set_buf_offset(con->in, remaining_buf(con->in));
@@ -1621,8 +1628,8 @@ static void _listen_accept(void *x)
 	con_mgr_fd_t *con = x;
 	con_mgr_t *mgr = con->mgr;
 	int rc;
-	struct sockaddr *addr = xmalloc(sizeof(*addr));
-	socklen_t addrlen = sizeof(*addr);
+	socklen_t addrlen = sizeof(struct sockaddr_storage);
+	struct sockaddr *addr = xmalloc(addrlen);
 	int fd;
 
 	_check_magic_fd(con);
@@ -1668,7 +1675,7 @@ static void _listen_accept(void *x)
 	}
 
 	xassert(addrlen > 0);
-	xassert(addrlen <= sizeof(*addr));
+	xassert(addrlen <= sizeof(struct sockaddr_storage));
 
 	/* hand over FD for normal processing */
 	if ((rc = _con_mgr_process_fd_internal(mgr, con, fd, fd, con->events,
@@ -1699,8 +1706,8 @@ extern int con_mgr_queue_write_fd(con_mgr_fd_t *con, const void *buffer,
 		grow_buf(con->out, need);
 	}
 
-	memcpy(get_buf_data(con->out) + get_buf_offset(con->out), buffer,
-	       bytes);
+	memmove((get_buf_data(con->out) + get_buf_offset(con->out)), buffer,
+		bytes);
 	con->out->processed += bytes;
 
 	log_flag(NET, "%s: [%s] queued %zu/%u bytes in outgoing buffer",
